import 'dart:io';

import 'package:args/args.dart';
import 'package:path/path.dart' as path;

import 'app.build.gradle.dart' as app;
import 'build.gradle.dart';
import 'google-service.json.dart';
import 'google_service_info.plist.dart';
import 'gradle.properties.dart';
import 'podfile.dart';
import 'project.pbxproj.dart';
import 'setting.gradle.dart';

const autoConfigDir = 'auto_config';

String get currentAbsolutePath => Directory.current.absolute.path;

void main(List<String> arguments) {
  final parser = ArgParser();
  parser.addCommand('android');
  parser.addCommand('ios');

  final argResult = parser.parse(arguments);

  var commandName = argResult.command?.name;

  switch (commandName) {
    case 'android':
      _autoConfigAndroid();
      print('auto config android is complete');
      break;
    case 'ios':
      _autoConfigIos();
      print('auto config ios is complete');
      break;
    default:
      _autoConfigAndroid();
      _autoConfigIos();
      print('auto config all is complete');
  }
}

/// 自动配置Android项
void _autoConfigAndroid() {
  _copyFile('gradle.properties', '.android', gradle_properties);
  _copyFile('settings.gradle', '.android', setting_gradle);
  _copyFile('google-services.json', '.android/app', google_service);
  _copyFile('build.gradle', '.android', build_gradle);
  _copyFile('build.gradle', '.android/app', app.build_gradle);
  //_copyFile('debug.keystore', '.android', '');
  //_copyFile('klook.keystore', '.android', '');
}

void _autoConfigIos() {
  _copyFile('Podfile', '.ios', podfile);
  _copyFile(
      'GoogleService-Info.plist', '.ios/Runner', google_service_info_plist);
  _copyFile('project.pbxproj', '.ios/Runner.xcodeproj', project_pbxproj);
}

/// 将[resource]的内容拷贝到目标路径[targetPath]中的[fileName]文件中
void _copyFile(String fileName, String targetPath, String resource) {
  final resourceFile =
      File(path.join(currentAbsolutePath, targetPath, fileName));

  // 如果文件不存在，则创建
  if (!resourceFile.existsSync()) {
    resourceFile.createSync();
  }

  // 覆盖写入
  resourceFile.writeAsStringSync(resource, mode: FileMode.write);
}
